aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--oni-core.el15
1 files changed, 13 insertions, 2 deletions
diff --git a/oni-core.el b/oni-core.el
index a0a20a5..b18560b 100644
--- a/oni-core.el
+++ b/oni-core.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2023.0415.204431
;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview mixed-pitch ace-window vertico marginalia orderless consult embark docstr)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -478,5 +478,16 @@ which normally have their errors suppressed."
(setq native-comp-async-report-warnings-errors 'silent)
+;;; Mini frame
+
+(require 'mini-frame)
+
+(setq mini-frame-show-parameters
+ '((top . 10)
+ (width . 0.7)
+ (left . 0.5)))
+
+(mini-frame-mode)
+
(provide 'oni-core)
;;; oni-core.el ends here
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2023.0415.204431
-;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview mixed-pitch ace-window vertico marginalia orderless consult embark docstr)
+;; Version: 2023.0416.003045
+;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview mixed-pitch ace-window vertico marginalia orderless consult embark docstr mini-frame)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by